function y = rar( x, fs, T_w, g, T_out, T_ref, fc, r, a, v, n )
%RADAR      simulate radar returns from a single pulse
%-----
%  Usage:
%    R = rar( X, Fs, T_w, G, T_out, T_ref, Fc, R, A, V )
%
%      X:      input pulse (vector containing one pulse for burst)
%      Fs:     sampling frequency of input pulse(s)      [in MHz]
%      T_w:    time(s) between sucessive pulses         [microsec]
%      G:      complex gains; # pulses = length(g)
%      T_out:  2-vector [T_min,T_max] defines output
%                window delay times w.r.t. start of pulse
%      T_ref:  system "reference" time, needed to simulate
%                 burst returns. THIS IS THE "t=0" TIME !!!
%      Fc:     center freq. of the radar.                [in MHz]
%      R:      vector of ranges to target(s)         [kilometers]
%      A:      (complex) vector of target amplitudes
%      V:      vector of target velocities (optional)  [in m/sec]
%      N:      noise
%
%  note(1): VELOCITY in meters/sec !!!
%           distances in km, times in microsec, BW in MegaHz.

%  note(2): assumes each pulse is constant (complex) amplitude
%  note(3): will accommodate up to quadratic phase pulses
%  note(4): vector of ranges, R, allows DISTRIBUTED targets
%

%---------------------------------------------------------------
% copyright 1994, by C.S. Burrus, J.H. McClellan, A.V. Oppenheim,
% T.W. Parks, R.W. Schafer, & H.W. Schussler.  For use with the book
% "Computer-Based Exercises for Signal Processing Using MATLAB"
% (Prentice-Hall, 1994).
%---------------------------------------------------------------

J = sqrt(-1);
c = 0.3;         % velocity of light in km/microsec
r = r(:);   a = a(:);
if nargin < 7
	v = zeros(length(r),1);
end   %--- default = 0 m/sec
[Mx, Nx] = size(x);
if Mx == 1
	old_Nx = Nx;   Mx = Nx;   Nx = 1;  x = x.';
end
if Nx ~= 1
	error('MATRIX x NOT ALLOWED !!!')
end
g = g(:).';      %-- gains of each pulse in burst
delta_t = 1/fs;
T_p = Mx*delta_t;     % length of input pulse
t_x = (delta_t)*[0:(Mx-1)]';
x_ph = unwrap(angle(x));       %-- find phase modulation
q = polyfit( t_x, x_ph, 2 );   %-- assume LFM signal
xfit = polyval( q, t_x );
if (x_ph'*xfit)/norm(x_ph)/norm(xfit) < 0.99   %-- correlation coeff
	disp(' no quadratic phase match')
end
%
%---  output matrix ---
%
Nr = length(g);     % output samples in a matrix
T_0=T_w.*(0:Nr-1);
T_e=T_w.*(1:Nr);
T_out=[0 Nr*T_w-delta_t];
t_y = [ T_out(1):delta_t:T_out(2) ]';  % output sampling times
Mr = length(t_y); 
t=1:Mr; 				% index for t_y array
y = zeros(Mr,1);

for  i = 1:length(r) 				% for each target
	ri = r(i);   vi = v(i)/(10^9);  % convert m/sec to km/usec
	f_doppler = 2*(vi/c)*fc;
	r_at_T_0 = ri - vi*T_0(1);    %-- toward rcvr: f_doppler > 0
	for l=1:Nr  					% for each pulse
		%-- toward rcvr: f_doppler > 0
		r_at_T_l = ri - vi*T_0(l);    %-- toward rcvr: f_doppler > 0
		    %-- toward rcvr: f_doppler > 0
		tau_l = r_at_T_l./(c+vi)./2;
		if T_0(l)+tau_l < T_0(l)
			disp('BEFORE range window'),  ri
		elseif T_0(l)+tau_l > T_e(l)
			disp('AFTER range window'),  ri
		else
			arg1=2*pi*fc*(t_y(t)-2*(r_at_T_0-vi*t_y(t))/c);
			%arg1=2*pi*fc*(-2*(r_at_T_0-vi*t_y(t))/c);
			arg2=t_y(t)-2*(r_at_T_0-vi*t_y(t))/c -T_0(l);
			%arg2=-2*(r_at_T_0-vi*t_y(t))/c -T_0(l);
			n_out=find( arg2>=0 & arg2<T_p );
			y(n_out)=y(n_out)+exp(J*arg1(n_out)).*exp(J*polyval(q,arg2(n_out))); 
		end
	end
end
y_len=size(y,1);
if n>0
	y=y+n*(randn(size(y))+J*randn(size(y)));
	%y=y+n*(randn(size(y));
end
%keyboard;
if rem(y_len,Nr)==0
	s_len=y_len/Nr;
	yy=zeros(s_len,Nr);
	for i = 1:Nr
		yy(1:s_len,i)=y((i-1)*s_len+1:i*s_len);
	end
	y=yy;
end
